# -*- coding: utf-8 -*-
"""This module ``phrase_detective.components`` implements ``spacy`` component for detecting noun phrase, prep phrase and verb phrase. 
"""

from .noun_phrases import NounPhraseRecognizer
from .prep_phrases import PrepPhraseRecognizer
from .verb_knowledge import VerbKnowledgeRecognizer
